Meet Sphinxit!
==============

.. image:: https://secure.travis-ci.org/semirook/sphinxit.png?branch=master

**Sphinxit** is light and powerful **SphinxQL** query constructor. More, it is the set of helpers
to make search with `Sphinx <http://sphinxsearch.com/>`_ easy to use in any kind of Python projects 
like Django, Flask and others. Sphinxit is independent Python library and you are free to use it 
anywhere you need powerful Sphinx-based search. 

Make full-text queries, filtering, ordering, grouping and aggregations.
Forget about deprecated Sphinx API or unpredictable non-tested batteries. Sphinxit is just better.

Documentation and examples are on RTD: http://sphinxit.readthedocs.org/
